==> BCTLSNetwork_5_2025-11-18_13.42.09.jar: ca/tecreations/net/TNData.java <==
package ca.tecreations.net;

import java.util.*;

/**
 *
 * @author tim
 */
public class TNData {
    public static String ilist = "chars";
    public static String MY_LIST; // for the author.
    public static String GOD_LIST; // need I say?
    public static String TIM_LIST; // here I will.
    public static String JESUS_LIST; // they said He is Preparing a Place for Us?
    public static String HOLY_SPIRIT_LIST; // I'm so bad.
     
    public static String NOW_INSTANT_INSTANCE; // The/Your current software version.
    
    public static String SUMTHING_BY_SOMEONE_SOMEWHERE_AT_NOW; // yours and when.
    
    public String BORN; // your birthdate.
    public String AT; // when the time was taken.
    public String TT_AFTER_BIRTH; // tim's time after YOUR birth for a tim's machine. Digital ocean (tecreations.ca) is set to Alberta 
                                  // (HEISLER) time.
    // oyp
    public String DIED_TT; // If the person is dead, the tims time ate which the person died. (Optional, hello.)
    
    public static final String reification_id = "MyJannaContact'95";
    // Vic20&Apple ][,IBM pc clone. 
    // Pascal, C, C++, Java. ROM BASIC.
    
    public static final String GET_COMMS_PORT = "GET_COMMS_PORT";
    
    
    public static final String SN = TNData.class.getSimpleName();
    
    public static final int SIXTY_GEES = 60000;
    
    public static final String ADD_GROUP = "ADD_GROUP";
    public static final String ADD_USER = "ADD_USER";
    public static final String BAN = "BAN";
    public static final String BUILD_JAVA = "BUILD_JAVA";
    public static final String CAN_EXECUTE = "CAN_EXECUTE";
    public static final String CAN_READ = "CAN_READ";
    public static final String CAN_WRITE = "CAN_WRITE";
    public static final String CLEAN = "CLEAN";
    public static final String CLOSE = "CLOSE";
    //public static String COPY_DIR = "COPY_DIR";
    //public static String COPY_FILE_TO_DIR = "COPY_FILE_TO_DIR";
    //public static String COPY_FILE_TO_FILE = "COPY_FILE_TO_FILE";
    public static final String DELETE = "DELETE";
    //public static int DELAY_2S = 2000; // adjust lower for faster servers
    public static String DIR = "DIR";
    public static final String DIR_EXISTS = "DIR_EXISTS";
    public static final String DIR_TIM = "DIR_TIM";
    //public static String DONE_BUILDING = "DONE_BUILDING";
    //public static String DO_PLATFORM_QUERY = "DO_PLATFORM_QUERY";
    public static final String EXEC_FOR_OUTPUT = "EXEC_FOR_OUTPUT";
    public static final String EXEC_FOR_OUTPUT_JAVA = "EXEC_FOR_OUTPUT_JAVA";
    public static final String EXEC_SPAWN = "EXEC_SPAWN";
    public static final String EXEC_SPAWN_JAVA = "EXEC_SPAWN_JAVA";
    public static final String EXISTS = "EXISTS";
    
    public static final String GET = "GET";
    public static final String GET_ALL = "GET_ALL";
    public static final String GET_CLIENT_PROPERTIES = "GET_CLIENT_PROPERTIES";
    public static final String GET_DIR_SIZE = "GET_DIR_SIZE";
    public static final String GET_DIR_SIZES = "GET_DIR_SIZES";
    public static final String GET_DOS_FILE_ATTRIBUTES = "GET_DOS_FILE_ATTRIBUTES";
    //public static String GET_ENV = "GET_ENV";
    public static final String GET_FILE_LINES = "GET_FILE_LINES";
    public static final String GET_FILE_SIZE = "GET_FILE_SIZE";
    public static final String GET_NEXT_DIRECTORY_NAME = "GET_NEXT_DIRECTORY_NAME"; 
    public static final String GET_NEXT_FILE_NAME = "GET_NEXT_FILE_NAME";
    public static final String GET_POSIX_FILE_PERMISSIONS = "GET_POSIX_FILE_PERMISSIONS";
    public static final String GET_POSIX_GROUP = "GET_POSIX_GROUP";
    public static final String GET_POSIX_GROUPS = "GET_POSIX_GROUPS";
    public static final String GET_POSIX_OWNER = "GET_POSIX_OWNER";
    public static final String GET_POSIX_USERS = "GET_POSIX_USERS";
    //public static final String GET_USERS = "GET_USERS";
    public static final String GET_SCREENSHOT_PATH = "GET_SCREENSHOT_PATH";
    public static final String GET_SERVER_PROPERTIES = "GET_SERVER_PROPERTIES";
    //public static String GET_SERVER_DEBUG = "GET_SERVER_DEBUG";
    public static final String GET_TIMS_TIME = "GET_TIMS_TIME";
    public static final String GET_USABLE_SPACE = "GET_USABLE_SPACE";
    //public static String GET_WEB_SNAPSHOT_DIR = "GET_WEB_SNAPSHOT_DIR";
    public static final String HAS_JAVA = "HAS_JAVA";
    public static final String HELP = "HELP";
    public static final String IS_DIR = "IS_DIR";
    public static final String IS_EXECUTABLE = "IS_EXECUTABLE";
    public static final String IS_FILE = "IS_FILE";
    public static final String IS_READABLE = "IS_READABLE";
    public static final String IS_WRITABLE = "IS_WRITABLE";
    public static final String LIST_ALL = "LIST_ALL";
    public static final String LIST_DIRS = "LIST_DIRS";
    public static final String LIST_FILES = "LIST_FILES";
    public static final String LIST_ITEM = "LIST_ITEM";   // full details, if exists, otherwise NON_EXISTENT
    public static final String LIST_NEWEST_DIRECTORY = "GET_NEWEST_DIRECTORY";
    public static final String LIST_NEWEST_FILE = "GET_NEWEST_FILE";
    public static final String LIST_OLDEST_DIRECTORY = "GET_OLDEST_DIRECTORY";
    public static final String LIST_OLDEST_FILE = "GET_OLDEST_FILE";
    public static final String LIST_ROOTS = "LIST_ROOTS";
    public static String LS = "LS";
    public static final String LS_TIM = "LS_TIM";
    public static final String MKDIRS = "MKDIRS";
    public static final String OK = "OK";
    public static final String PRUNE = "PRUNE";
    public static final String PUT = "PUT";
    public static final String RENAME = "RENAME";
    //public static String SEND_CLICK = "SEND_CLICK";
    //public static String SEND_DRAG = "SEND_DRAG";
    //public static String SEND_KEYS = "SEND_KEYS";
    //public static String SEND_MOUSE_DOWN = "SEND_MOUSE_DOWN";
    //public static String SEND_MOUSE_MOVE = "SEND_MOUSE_MOVE";
    //public static String SEND_MOUSE_UP = "SEND_MOUSE_UP";
    //public static String SEND_MSG = "SEND_MSG";
    //public static String SEND_TEXT = "SEND_TEXT";
    //public static String SEND_UTF8 = "SEND_UTF8";
    public static final String SET_DOS_FILE_ATTRIBUTES = "SET_DOS_FILE_ATTRIBUTES";
    //public static String SET_ENV = "SET_ENV";
    public static final String SET_EXECUTABLE = "SET_EXECUTABLE";
    public static final String SET_POSIX_FILE_PERMISSIONS = "SET_POSIX_FILE_PERMISSIONS";
    public static final String SET_POSIX_GROUP = "SET_POSIX_GROUP";
    public static final String SET_POSIX_OWNER = "SET_POSIX_OWNER";
    public static final String SET_READABLE = "SET_READABLE";
    //public static String SET_SERVER_DEBUG = "SET_SERVER_DEBUG";
    public static final String SET_WRITABLE = "SET_WRITABLE";
    public static final String SHUTDOWN = "SHUTDOWN";
    //public static String SHOW = "SHOW";
    //public static String STATUS = "STATUS";
    public static final String STOP_THIS_CLIENT = "STOP_THIS_CLIENT";
    public static final String TAKE_SCREENSHOT = "TAKE_SCREENSHOT";
    public static final String TOGGLE_EXECUTABLE = "TOGGLE_EXECUTABLE";
    public static final String TOGGLE_READABLE = "TOGGLE_READABLE";
    public static final String TOGGLE_WRITABLE = "TOGGLE_WRITABLE";

}

==> BCTLSNetwork_10_2025-11-29_18.21.01.jar: ca/tecreations/net/TNData.java <==
package ca.tecreations.net;

import java.util.*;

/**
 *
 * @author tim
 */
public class TNData {
    public static String ilist = "chars";
    public static String MY_LIST; // for the author.
    public static String GOD_LIST; // need I say?
    public static String TIM_LIST; // here I will.
    public static String JESUS_LIST; // they said He is Preparing a Place for Us?
    public static String HOLY_SPIRIT_LIST; // I'm so bad.
     
    public static String NOW_INSTANT_INSTANCE; // The/Your current software version.
    
    public static String SUMTHING_BY_SOMEONE_SOMEWHERE_AT_NOW; // yours and when.
    
    public String BORN; // your birthdate.
    public String AT; // when the time was taken.
    public String TT_AFTER_BIRTH; // tim's time after YOUR birth for a tim's machine. Digital ocean (tecreations.ca) is set to Alberta 
                                  // (HEISLER) time.
    // oyp
    public String DIED_TT; // If the person is dead, the tims time ate which the person died. (Optional, hello.)
    
    public static final String reification_id = "MyJannaContact'95";
    // Vic20&Apple ][,IBM pc clone. 
    // Pascal, C, C++, Java. ROM BASIC.
    
    public static final String GET_COMMS_PORT = "GET_COMMS_PORT";
    
    
    public static final String SN = TNData.class.getSimpleName();
    
    public static final int SIXTY_GEES = 60000;
    
    public static final String ADD_GROUP = "ADD_GROUP";
    public static final String ADD_USER = "ADD_USER";
    public static final String BAN = "BAN";
    public static final String BUILD_JAVA = "BUILD_JAVA";
    public static final String CAN_EXECUTE = "CAN_EXECUTE";
    public static final String CAN_READ = "CAN_READ";
    public static final String CAN_WRITE = "CAN_WRITE";
    public static final String CLEAN = "CLEAN";
    public static final String CLOSE = "CLOSE";
    //public static String COPY_DIR = "COPY_DIR";
    //public static String COPY_FILE_TO_DIR = "COPY_FILE_TO_DIR";
    //public static String COPY_FILE_TO_FILE = "COPY_FILE_TO_FILE";
    public static final String DELETE = "DELETE";
    //public static int DELAY_2S = 2000; // adjust lower for faster servers
    public static String DIR = "DIR";
    public static final String DIR_EXISTS = "DIR_EXISTS";
    public static final String DIR_TIM = "DIR_TIM";
    //public static String DONE_BUILDING = "DONE_BUILDING";
    //public static String DO_PLATFORM_QUERY = "DO_PLATFORM_QUERY";
    public static final String EXEC_FOR_OUTPUT = "EXEC_FOR_OUTPUT";
    public static final String EXEC_FOR_OUTPUT_JAVA = "EXEC_FOR_OUTPUT_JAVA";
    public static final String EXEC_SPAWN = "EXEC_SPAWN";
    public static final String EXEC_SPAWN_JAVA = "EXEC_SPAWN_JAVA";
    public static final String EXISTS = "EXISTS";
    
    public static final String GET = "GET";
    public static final String GET_ALL = "GET_ALL";
    public static final String GET_CLIENT_PROPERTIES = "GET_CLIENT_PROPERTIES";
    public static final String GET_DIR_SIZE = "GET_DIR_SIZE";
    public static final String GET_DIR_SIZES = "GET_DIR_SIZES";
    public static final String GET_DOS_FILE_ATTRIBUTES = "GET_DOS_FILE_ATTRIBUTES";
    //public static String GET_ENV = "GET_ENV";
    public static final String GET_FILE_LINES = "GET_FILE_LINES";
    public static final String GET_FILE_SIZE = "GET_FILE_SIZE";
    public static final String GET_NEXT_DIRECTORY_NAME = "GET_NEXT_DIRECTORY_NAME"; 
    public static final String GET_NEXT_FILE_NAME = "GET_NEXT_FILE_NAME";
    public static final String GET_POSIX_FILE_PERMISSIONS = "GET_POSIX_FILE_PERMISSIONS";
    public static final String GET_POSIX_GROUP = "GET_POSIX_GROUP";
    public static final String GET_POSIX_GROUPS = "GET_POSIX_GROUPS";
    public static final String GET_POSIX_USER = "GET_POSIX_USER";
    public static final String GET_POSIX_USERS = "GET_POSIX_USERS";
    //public static final String GET_USERS = "GET_USERS";
    public static final String GET_SCREENSHOT_PATH = "GET_SCREENSHOT_PATH";
    public static final String GET_SERVER_PROPERTIES = "GET_SERVER_PROPERTIES";
    //public static String GET_SERVER_DEBUG = "GET_SERVER_DEBUG";
    public static final String GET_TIMS_TIME = "GET_TIMS_TIME";
    public static final String GET_USABLE_SPACE = "GET_USABLE_SPACE";
    //public static String GET_WEB_SNAPSHOT_DIR = "GET_WEB_SNAPSHOT_DIR";
    public static final String HAS_JAVA = "HAS_JAVA";
    public static final String HELP = "HELP";
    public static final String IS_DIR = "IS_DIR";
    public static final String IS_EXECUTABLE = "IS_EXECUTABLE";
    public static final String IS_FILE = "IS_FILE";
    public static final String IS_READABLE = "IS_READABLE";
    public static final String IS_WRITABLE = "IS_WRITABLE";
    public static final String LIST_ALL = "LIST_ALL";
    public static final String LIST_DIRS = "LIST_DIRS";
    public static final String LIST_FILES = "LIST_FILES";
    public static final String LIST_ITEM = "LIST_ITEM";   // full details, if exists, otherwise NON_EXISTENT
    public static final String LIST_NEWEST_DIRECTORY = "GET_NEWEST_DIRECTORY";
    public static final String LIST_NEWEST_FILE = "GET_NEWEST_FILE";
    public static final String LIST_OLDEST_DIRECTORY = "GET_OLDEST_DIRECTORY";
    public static final String LIST_OLDEST_FILE = "GET_OLDEST_FILE";
    public static final String LIST_ROOTS = "LIST_ROOTS";
    public static String LS = "LS";
    public static final String LS_TIM = "LS_TIM";
    public static final String MKDIRS = "MKDIRS";
    public static final String OK = "OK";
    public static final String PRUNE = "PRUNE";
    public static final String PUT = "PUT";
    public static final String RENAME = "RENAME";
    //public static String SEND_CLICK = "SEND_CLICK";
    //public static String SEND_DRAG = "SEND_DRAG";
    //public static String SEND_KEYS = "SEND_KEYS";
    //public static String SEND_MOUSE_DOWN = "SEND_MOUSE_DOWN";
    //public static String SEND_MOUSE_MOVE = "SEND_MOUSE_MOVE";
    //public static String SEND_MOUSE_UP = "SEND_MOUSE_UP";
    //public static String SEND_MSG = "SEND_MSG";
    //public static String SEND_TEXT = "SEND_TEXT";
    //public static String SEND_UTF8 = "SEND_UTF8";
    public static final String SET_DOS_FILE_ATTRIBUTES = "SET_DOS_FILE_ATTRIBUTES";
    //public static String SET_ENV = "SET_ENV";
    public static final String SET_EXECUTABLE = "SET_EXECUTABLE";
    public static final String SET_POSIX_FILE_PERMISSIONS = "SET_POSIX_FILE_PERMISSIONS";
    public static final String SET_POSIX_GROUP = "SET_POSIX_GROUP";
    public static final String SET_POSIX_USER = "SET_POSIX_USER";
    public static final String SET_READABLE = "SET_READABLE";
    //public static String SET_SERVER_DEBUG = "SET_SERVER_DEBUG";
    public static final String SET_WRITABLE = "SET_WRITABLE";
    public static final String SHUTDOWN = "SHUTDOWN";
    //public static String SHOW = "SHOW";
    //public static String STATUS = "STATUS";
    public static final String STOP_THIS_CLIENT = "STOP_THIS_CLIENT";
    public static final String TAKE_SCREENSHOT = "TAKE_SCREENSHOT";
    public static final String TOGGLE_EXECUTABLE = "TOGGLE_EXECUTABLE";
    public static final String TOGGLE_READABLE = "TOGGLE_READABLE";
    public static final String TOGGLE_WRITABLE = "TOGGLE_WRITABLE";

}
